@@ -29,6 +29,10 @@ class api:
     getInvoiceItemPriceURL = baseUrl + "/webservices/GeneralAjaxService.asmx/GetInvoiceItemPrice"
     getPriceListItemURL = baseUrl + "/webservices/GeneralAjaxService.asmx/GetPriceListItem"
     getNewItemForQuoteURL = baseUrl + "/webservices/QuoteService.asmx/GetNewItemForQuote"
+    getDriversURL = baseUrl + "/webservices/Drivers.asmx/GetAllDrivers"
+    getEquipmentURL = baseUrl + "/webservices/GeneralAjaxService.asmx/GetEquipment"
+    getEmployeesURL = baseUrl + "/webservices/Employees.asmx/GetDrivers"
+    getSubItemsURL = baseUrl + "/webservices/GeneralAjaxService.asmx/GetSubItems"
 
     def __init__(self, email=None, password=None):
         self.tcr_auth = auth(email, password)
@@ -374,12 +378,7 @@ class api:
         -------
             dict -- Items
         """
-        dateKeys = ["LastOrderDate", "DateCreated", "DateUpdated"]
         response = requests.post(self.getItemsURL, headers=self.headers).json()
-        for item in response["d"]:
-            for key in dateKeys:
-                if item[key] is not None:
-                    item[key] = millisecond_stamp_to_datetime(item[key])
         return response["d"]
 
     def getPriceLists(self):
@@ -474,4 +473,81 @@ class api:
         response = requests.post(self.getCompanyURL, headers=self.headers).json()
         responseD = response["d"]
         responseD.pop("LogoImage")
-        return responseD
\ No newline at end of file
+        return responseD
+
+    def getDrivers(self):
+        """
+        Gets All Drivers From TCR
+        
+        Returns::
+        -------
+            list - All Drivers
+        """
+        response = requests.post(self.getDriversURL, headers=self.headers).json()
+        dateKeys = ["LocationDate", "DateCreated", "DateUpdated"]
+        responseD = response["d"]
+        for key in dateKeys:
+            if responseD[key] is not None:
+                responseD[key] = millisecond_stamp_to_datetime(responseD[key])
+            if responseD["OriginalRecordData"][key] is not None:
+                responseD["OriginalRecordData"][key] = millisecond_stamp_to_datetime(responseD["OriginalRecordData"][key])
+        return responseD
+
+    def getEmployees(self):
+        """
+        Gets All Employees From TCR
+        
+        Returns::
+        -------
+            list - All Employees
+        """
+        response = requests.post(self.getEmployeesURL, headers=self.headers).json()
+        dateKeys = ["DateCreated", "DateUpdated"]
+        responseD = response["d"]
+        for key in dateKeys:
+            if responseD[key] is not None:
+                responseD[key] = millisecond_stamp_to_datetime(responseD[key])
+            if responseD["OriginalRecordData"][key] is not None:
+                responseD["OriginalRecordData"][key] = millisecond_stamp_to_datetime(responseD["OriginalRecordData"][key])
+        return responseD
+
+    def getEquipment(self, EquipmentID):
+        """
+        Gets All Equipment From TCR
+
+        Parameters::
+        ----------
+            EquipmentID -- Equipment ID : int
+        
+        Returns::
+        -------
+            list - All Equipment
+        """
+        requestData = {"equipID": EquipmentID}
+        response = requests.post(self.getEquipmentURL, headers=self.headers, json=requestData).json()
+        dateKeys = ["DateCreated", "DateInService", "DateUpdated", "DateOutofService"]
+        responseD = response["d"]
+        for key in dateKeys:
+            if responseD[key] is not None:
+                responseD[key] = millisecond_stamp_to_datetime(responseD[key])
+            if responseD["OriginalRecordData"][key] is not None:
+                responseD["OriginalRecordData"][key] = millisecond_stamp_to_datetime(responseD["OriginalRecordData"][key])
+        return responseD
+
+    def getSubItems(self):
+        """
+        Gets All Sub Items From TCR
+        
+        Returns::
+        -------
+            list - All Sub Items
+        """
+        response = requests.post(self.getSubItemsURL, headers=self.headers).json()
+        dateKeys = ["DateCreated", "DateUpdated"]
+        responseD = response["d"]
+        for key in dateKeys:
+            if responseD[key] is not None:
+                responseD[key] = millisecond_stamp_to_datetime(responseD[key])
+            if responseD["OriginalRecordData"][key] is not None:
+                responseD["OriginalRecordData"][key] = millisecond_stamp_to_datetime(responseD["OriginalRecordData"][key])
+        return responseD
